package com.ruoyi.base.service;

import java.util.List;
import com.ruoyi.base.domain.BaseAlarmInfo;

/**
 * 报警信息Service接口
 * 
 * @author zangch
 * @date 2024-12-02
 */
public interface IBaseAlarmInfoService 
{
    /**
     * 查询报警信息
     * 
     * @param objId 报警信息主键
     * @return 报警信息
     */
    public BaseAlarmInfo selectBaseAlarmInfoByObjId(Long objId);

    /**
     * 查询报警信息列表
     * 
     * @param baseAlarmInfo 报警信息
     * @return 报警信息集合
     */
    public List<BaseAlarmInfo> selectBaseAlarmInfoList(BaseAlarmInfo baseAlarmInfo);

    /**
     * 新增报警信息
     * 
     * @param baseAlarmInfo 报警信息
     * @return 结果
     */
    public int insertBaseAlarmInfo(BaseAlarmInfo baseAlarmInfo);

    /**
     * 修改报警信息
     * 
     * @param baseAlarmInfo 报警信息
     * @return 结果
     */
    public int updateBaseAlarmInfo(BaseAlarmInfo baseAlarmInfo);

    /**
     * 批量删除报警信息
     * 
     * @param objIds 需要删除的报警信息主键集合
     * @return 结果
     */
    public int deleteBaseAlarmInfoByObjIds(Long[] objIds);

    /**
     * 删除报警信息信息
     * 
     * @param objId 报警信息主键
     * @return 结果
     */
    public int deleteBaseAlarmInfoByObjId(Long objId);
}
